from rest_framework import generics, permissions

from posts.models import Post
from .serializers import PostSerializer
from .permissions import IsAuthorOrReadOnlyPermission
from .throttling import LunchBreakThrottle
from rest_framework.throttling import ScopedRateThrottle


class PostList(generics.ListCreateAPIView):
    queryset = Post.objects.all()
    serializer_class = PostSerializer
    permission_classes = (permissions.IsAuthenticatedOrReadOnly,)
    throttle_classes = (LunchBreakThrottle, ScopedRateThrottle)

    def perform_create(self, serializer):
        serializer.save(author=self.request.user)


class PostDetail(generics.RetrieveUpdateDestroyAPIView):
    queryset = Post.objects.all()
    serializer_class = PostSerializer
    permission_classes = (IsAuthorOrReadOnlyPermission,)
    throttle_classes = (LunchBreakThrottle, ScopedRateThrottle)